@@ -398,7 +398,7 @@ void SCH_EDIT_FRAME::setupUIConditions()
 {
     SCH_BASE_FRAME::setupUIConditions();
 
-    ACTION_MANAGER*   mgr = m_toolManager->GetActionManager();
+    ACTION_MANAGER*       mgr = m_toolManager->GetActionManager();
     SCH_EDITOR_CONDITIONS cond( this );
 
     wxASSERT( mgr );
@@ -417,11 +417,20 @@ void SCH_EDIT_FRAME::setupUIConditions()
             };
 
 
+    auto undoCond =
+            [ this ] (const SELECTION& aSel )
+            {
+                if( SCH_LINE_WIRE_BUS_TOOL::IsDrawingLineWireOrBus( aSel ) )
+                    return true;
+
+                return GetUndoCommandCount() > 0;
+            };
+
 #define ENABLE( x ) ACTION_CONDITIONS().Enable( x )
 #define CHECK( x )  ACTION_CONDITIONS().Check( x )
 
     mgr->SetConditions( ACTIONS::save,                ENABLE( SELECTION_CONDITIONS::ShowAlways ) );
-    mgr->SetConditions( ACTIONS::undo,                ENABLE( cond.UndoAvailable() ) );
+    mgr->SetConditions( ACTIONS::undo,                ENABLE( undoCond ) );
     mgr->SetConditions( ACTIONS::redo,                ENABLE( cond.RedoAvailable() ) );
 
     mgr->SetConditions( EE_ACTIONS::showHierarchy,    CHECK( hierarchyNavigatorCond ) );
@@ -1487,9 +1496,10 @@ void SCH_EDIT_FRAME::RecalculateConnections( SCH_CLEANUP_FLAGS aCleanupFlags )
     }
     else
     {
-        auto& changed_list = m_undoList.m_CommandsList.back();
+        PICKED_ITEMS_LIST* changed_list = m_undoList.m_CommandsList.back();
         std::set<SCH_ITEM*> changed_items;
         std::vector<VECTOR2I> pts;
+        std::set<std::pair<SCH_SHEET_PATH, SCH_ITEM*>> item_paths;
 
         for( unsigned ii = 0; ii < changed_list->GetCount(); ++ii )
         {
@@ -1498,11 +1508,16 @@ void SCH_EDIT_FRAME::RecalculateConnections( SCH_CLEANUP_FLAGS aCleanupFlags )
             if( !item || !IsEeschemaType( item->Type() ) )
                 continue;
 
+            SCH_SCREEN* screen = static_cast<SCH_SCREEN*>( changed_list->GetScreenForItem( ii ) );
             SCH_ITEM* sch_item = static_cast<SCH_ITEM*>( item );
+            SCH_SHEET_PATHS& paths = screen->GetClientSheetPaths();
 
             std::vector<VECTOR2I> tmp_pts = sch_item->GetConnectionPoints();
             pts.insert( pts.end(), tmp_pts.begin(), tmp_pts.end() );
             changed_items.insert( sch_item );
+
+            for( SCH_SHEET_PATH& path : paths )
+                item_paths.insert( std::make_pair( path, sch_item ) );
         }
 
         for( VECTOR2I& pt: pts )
@@ -1537,6 +1552,8 @@ void SCH_EDIT_FRAME::RecalculateConnections( SCH_CLEANUP_FLAGS aCleanupFlags )
                 Schematic().ConnectionGraph()->ExtractAffectedItems(
                         changed_items );
 
+        all_items.insert( item_paths.begin(), item_paths.end() );
+
         CONNECTION_GRAPH new_graph( &Schematic() );
 
         new_graph.SetLastCodes( Schematic().ConnectionGraph() );
@@ -1547,7 +1564,6 @@ void SCH_EDIT_FRAME::RecalculateConnections( SCH_CLEANUP_FLAGS aCleanupFlags )
             {
             case SCH_FIELD_T:
             case SCH_PIN_T:
-            case SCH_SHEET_PIN_T:
                 static_cast<SCH_ITEM*>( item->GetParent() )->SetConnectivityDirty();
                 break;
 
