@@ -499,7 +499,7 @@ bool SHAPE_POLY_SET::IsPolygonSelfIntersecting( int aPolygonIndex ) const
                 break;
 
             int index_diff = std::abs( firstSegment.Index() - secondSegment.Index() );
-            bool adjacent = ( index_diff == 1) || (index_diff == (segments.size() - 1) ); 
+            bool adjacent = ( index_diff == 1) || (index_diff == ((int)segments.size() - 1) );
 
             // Check whether the two segments built collide, only when they are not adjacent.
             if( !adjacent && firstSegment.Collide( secondSegment, 0 ) )
@@ -992,7 +992,8 @@ void SHAPE_POLY_SET::inflate1( int aAmount, int aCircleSegCount, CORNER_STRATEGY
 }
 
 
-void SHAPE_POLY_SET::inflate2( int aAmount, int aCircleSegCount, CORNER_STRATEGY aCornerStrategy )
+void SHAPE_POLY_SET::inflate2( int aAmount, int aCircleSegCount, CORNER_STRATEGY aCornerStrategy,
+        bool aSimplify )
 {
     using namespace Clipper2Lib;
     // A static table to avoid repetitive calculations of the coefficient
@@ -1008,28 +1009,27 @@ void SHAPE_POLY_SET::inflate2( int aAmount, int aCircleSegCount, CORNER_STRATEGY
     // http://www.angusj.com/delphi/clipper/documentation/Docs/Units/ClipperLib/Types/JoinType.htm
     JoinType joinType = JoinType::Round;    // The way corners are offsetted
     double   miterLimit = 2.0;      // Smaller value when using jtMiter for joinType
-    JoinType miterFallback = JoinType::Square;
 
     switch( aCornerStrategy )
     {
-    case ALLOW_ACUTE_CORNERS:
+    case CORNER_STRATEGY::ALLOW_ACUTE_CORNERS:
         joinType = JoinType::Miter;
         miterLimit = 10;        // Allows large spikes
         break;
 
-    case CHAMFER_ACUTE_CORNERS: // Acute angles are chamfered
+    case CORNER_STRATEGY::CHAMFER_ACUTE_CORNERS: // Acute angles are chamfered
         joinType = JoinType::Miter;
         break;
 
-    case ROUND_ACUTE_CORNERS:   // Acute angles are rounded
+    case CORNER_STRATEGY::ROUND_ACUTE_CORNERS: // Acute angles are rounded
         joinType = JoinType::Miter;
         break;
 
-    case CHAMFER_ALL_CORNERS:   // All angles are chamfered.
+    case CORNER_STRATEGY::CHAMFER_ALL_CORNERS: // All angles are chamfered.
         joinType = JoinType::Square;
         break;
 
-    case ROUND_ALL_CORNERS:     // All angles are rounded.
+    case CORNER_STRATEGY::ROUND_ALL_CORNERS: // All angles are rounded.
         joinType = JoinType::Round;
         break;
     }
@@ -1072,17 +1072,35 @@ void SHAPE_POLY_SET::inflate2( int aAmount, int aCircleSegCount, CORNER_STRATEGY
     c.MiterLimit( miterLimit );
 
     PolyTree64 tree;
-    c.Execute( aAmount, tree );
+
+    if( aSimplify )
+    {
+        Paths64 paths;
+        c.Execute( aAmount, paths );
+
+        Clipper2Lib::SimplifyPaths( paths, std::abs( aAmount ) * coeff, true );
+
+        Clipper64 c2;
+        c2.PreserveCollinear( false );
+        c2.ReverseSolution( false );
+        c2.AddSubject( paths );
+        c2.Execute(ClipType::Union, FillRule::Positive, tree);
+    }
+    else
+    {
+        c.Execute( aAmount, tree );
+    }
 
     importTree( tree, zValues, arcBuffer );
     tree.Clear();
 }
 
 
-void SHAPE_POLY_SET::Inflate( int aAmount, int aCircleSegCount, CORNER_STRATEGY aCornerStrategy )
+void SHAPE_POLY_SET::Inflate( int aAmount, int aCircleSegCount, CORNER_STRATEGY aCornerStrategy,
+        bool aSimplify )
 {
     if( ADVANCED_CFG::GetCfg().m_UseClipper2 )
-        inflate2( aAmount, aCircleSegCount, aCornerStrategy );
+        inflate2( aAmount, aCircleSegCount, aCornerStrategy, aSimplify );
     else
         inflate1( aAmount, aCircleSegCount, aCornerStrategy );
 }
@@ -2473,6 +2491,13 @@ SHAPE_POLY_SET::POLYGON SHAPE_POLY_SET::chamferFilletPolygon( CORNER_MODE aMode,
             double xb = currContour.CPoint( nextVertex ).x - x1;
             double yb = currContour.CPoint( nextVertex ).y - y1;
 
+            // Avoid segments that will generate nans below
+            if( std::abs( xa + xb ) < std::numeric_limits<double>::epsilon()
+                    && std::abs( ya + yb ) < std::numeric_limits<double>::epsilon() )
+            {
+                continue;
+            }
+
             // Compute the new distances
             double  lena    = hypot( xa, ya );
             double  lenb    = hypot( xb, yb );
@@ -2555,6 +2580,9 @@ SHAPE_POLY_SET::POLYGON SHAPE_POLY_SET::chamferFilletPolygon( CORNER_MODE aMode,
                 double  nx  = xc + xs;
                 double  ny  = yc + ys;
 
+                if( std::isnan( nx ) || std::isnan( ny ) )
+                    continue;
+
                 newContour.Append( KiROUND( nx ), KiROUND( ny ) );
 
                 // Store the previous added corner to make a sanity check
@@ -2566,6 +2594,9 @@ SHAPE_POLY_SET::POLYGON SHAPE_POLY_SET::chamferFilletPolygon( CORNER_MODE aMode,
                     nx = xc + cos( startAngle + ( j + 1 ) * deltaAngle ) * radius;
                     ny = yc - sin( startAngle + ( j + 1 ) * deltaAngle ) * radius;
 
+                    if( std::isnan( nx ) || std::isnan( ny ) )
+                        continue;
+
                     // Sanity check: the rounding can produce repeated corners; do not add them.
                     if( KiROUND( nx ) != prevX || KiROUND( ny ) != prevY )
                     {
@@ -2793,10 +2824,7 @@ void SHAPE_POLY_SET::CacheTriangulation( bool aPartition, bool aSimplify )
 
         tmpSet.ClearArcs();
 
-        if( tmpSet.HasHoles() || tmpSet.IsSelfIntersecting() )
-            tmpSet.Fracture( PM_FAST );
-        else if( aSimplify )
-            tmpSet.Simplify( PM_FAST );
+        tmpSet.Fracture( PM_FAST );
 
         m_triangulationValid = triangulate( tmpSet, -1, m_triangulatedPolys );
     }
