@@ -1243,7 +1243,6 @@ bool PANEL_SETUP_BOARD_STACKUP::TransferDataFromWindow()
     // on that panel and it doesn't make sense to split it up.
 
     BOARD_STACKUP& brd_stackup = m_brdSettings->GetStackupDescriptor();
-
     STRING_FORMATTER old_stackup;
 
     // FormatBoardStackup() (using FormatInternalUnits()) expects a "C" locale
@@ -1251,12 +1250,6 @@ bool PANEL_SETUP_BOARD_STACKUP::TransferDataFromWindow()
     LOCALE_IO dummy;
     brd_stackup.FormatBoardStackup( &old_stackup, m_board, 0 );
 
-    brd_stackup.m_FinishType = m_stackup.m_FinishType;
-    brd_stackup.m_HasDielectricConstrains = m_stackup.m_HasDielectricConstrains;
-    brd_stackup.m_EdgeConnectorConstraints = m_stackup.m_EdgeConnectorConstraints;
-    brd_stackup.m_CastellatedPads = m_stackup.m_CastellatedPads;
-    brd_stackup.m_EdgePlating = m_stackup.m_EdgePlating;
-
     // copy enabled items to the new board stackup
     brd_stackup.RemoveAll();
 
@@ -1278,6 +1271,12 @@ bool PANEL_SETUP_BOARD_STACKUP::TransferDataFromWindow()
         modified = true;
     }
 
+    if( brd_stackup.m_HasDielectricConstrains != m_impedanceControlled->GetValue() )
+    {
+        brd_stackup.m_HasDielectricConstrains = m_impedanceControlled->GetValue();
+        modified = true;
+    }
+
     if( !m_brdSettings->m_HasStackup )
     {
         m_brdSettings->m_HasStackup = true;
